@@ -3,7 +3,7 @@ kegga <- function(de,...) UseMethod("kegga")
 kegga.MArrayLM <- function(de, coef = ncol(de), geneid = rownames(de), FDR = 0.05, trend = FALSE, ...)
 #	KEGG (Kyoto Encyclopedia of Genes and Genomes) pathway analysis of DE genes from linear model fit
 #	Gordon Smyth and Yifang Hu
-#	Created 15 May 2015. Last modified 3 June 2015.
+#	Created 15 May 2015. Last modified 11 Sep 2022.
 {
 #	Avoid argument collision with default method
 	dots <- names(list(...))
@@ -35,15 +35,17 @@ kegga.MArrayLM <- function(de, coef = ncol(de), geneid = rownames(de), FDR = 0.0
 		if(trend) {
 			covariate <- de$Amean
 			if(is.null(covariate)) stop("Amean not found in fit")
+		} else {
+			covariate <- NULL
 		}
 	} else {
 		if(is.numeric(trend)) {
-			if(length(trend) != ngenes) stop("If trend is numeric, then length must equal nrow(de)")
+			if(!identical(length(trend),ngenes)) stop("If trend is numeric, then length must equal nrow(de)")
 			covariate <- trend
 			trend <- TRUE
 		} else {
 			if(is.character(trend)) {
-				if(length(trend) != 1L) stop("If trend is character, then length must be 1")
+				if(!identical(length(trend),1L)) stop("If trend is character, then length must be 1")
 				covariate <- de$genes[[trend]]
 				if(is.null(covariate)) stop("Column ",trend," not found in de$genes")
 				trend <- TRUE
@@ -52,32 +54,41 @@ kegga.MArrayLM <- function(de, coef = ncol(de), geneid = rownames(de), FDR = 0.0
 		}
 	}
 
+#	Check for NA gene IDs or covariate values
+	if(anyNA(universe) || anyNA(covariate)) {
+		isna <- is.na(universe)
+		if(all(isna)) stop("Gene IDs are all NA")
+		if(trend) {
+			isna[is.na(covariate)] <- TRUE
+			covariate <- covariate[!isna]
+		}
+		universe <- universe[!isna]
+		de <- de[!isna,]
+	}
+
 #	Check FDR
 	if(!is.numeric(FDR) | length(FDR) != 1) stop("FDR must be numeric and of length 1.")
-	if(FDR < 0 | FDR > 1) stop("FDR should be between 0 and 1.")
+	if(FDR < 0 || FDR > 1) stop("FDR should be between 0 and 1.")
 
 #	Get up and down DE genes
 	fdr.coef <- p.adjust(de$p.value[,coef], method = "BH")
-	EG.DE.UP <- universe[fdr.coef < FDR & de$coef[,coef] > 0]
-	EG.DE.DN <- universe[fdr.coef < FDR & de$coef[,coef] < 0]
+	EG.DE.UP <- universe[fdr.coef < FDR & de$coefficients[,coef] > 0]
+	EG.DE.DN <- universe[fdr.coef < FDR & de$coefficients[,coef] < 0]
 	DEGenes <- list(Up=EG.DE.UP, Down=EG.DE.DN)
 
 #	If no DE genes, return data.frame with 0 rows
-	if(length(EG.DE.UP)==0 && length(EG.DE.DN)==0) {
+	if( identical(length(EG.DE.UP),0L) && identical(length(EG.DE.DN),0L) ) {
 		message("No DE genes")
 		return(data.frame())
 	}
 
-	if(trend)
-		kegga(de=DEGenes, universe = universe, covariate=covariate, ...)
-	else
-		kegga(de=DEGenes, universe = universe, ...)
+	kegga(de=DEGenes, universe = universe, covariate=covariate, ...)
 }
 
-kegga.default <- function(de, universe=NULL,  restrict.universe=FALSE, species="Hs", species.KEGG=NULL, convert=FALSE, gene.pathway=NULL, pathway.names = NULL,prior.prob=NULL, covariate=NULL, plot=FALSE, ...)
+kegga.default <- function(de, universe=NULL,  restrict.universe=FALSE, species="Hs", species.KEGG=NULL, convert=FALSE, gene.pathway=NULL, pathway.names = NULL,null.prob=NULL, covariate=NULL, plot=FALSE, ...)
 #	KEGG (Kyoto Encyclopedia of Genes and Genomes) pathway analysis of DE genes
 #	Gordon Smyth and Yifang Hu
-#	Created 18 May 2015.  Modified 18 May 2021.
+#	Created 18 May 2015.  Modified 11 Sep 2022.
 {
 #	Ensure de is a list
 	if(is.list(de)) {
@@ -139,26 +150,42 @@ kegga.default <- function(de, universe=NULL,  restrict.universe=FALSE, species="
 	}
 
 #	Universe defaults to all annotated genes
-#	prior.prob and covariate must have same length as universe
+#	null.prob and covariate must have same length as universe
 #	Ensure universe unique
 	if(is.null(universe)) {
 		universe <- unique(GeneID.PathID[,1])
-		prior.prob <- covariate <- NULL
+		if( !(is.null(null.prob) && is.null(covariate)) ) {
+			message("Ignoring covariate and null.prob because universe not set")
+			null.prob <- covariate <- NULL
+		}
 	} else {
 		universe <- as.character(universe)
 		lu <- length(universe)
-		if(!lu) stop("No genes in universe")
-		if(!is.null(prior.prob) && length(prior.prob)!=lu) stop("universe and prior.prob must have same length")
-		if(!is.null(covariate) && length(covariate)!=lu) stop("universe and covariate must have same length")
+		if(identical(lu,0L)) stop("No genes in universe")
+		if( !is.null(null.prob) && !identical(length(null.prob),lu) ) stop("universe and null.prob must have same length")
+		if( !is.null(covariate)  && !identical(length(covariate),lu)  ) stop("universe and covariate must have same length")
+		if(anyNA(universe) || anyNA(covariate) || anyNA(null.prob)) {
+			isna <- is.na(universe)
+			if(all(isna)) stop("Gene IDs are all NA")
+			if(!is.null(covariate)) {
+				isna[is.na(covariate)] <- TRUE
+				covariate <- covariate[!isna]
+			}
+			if(!is.null(null.prob)) {
+				isna[is.na(null.prob)] <- TRUE
+				null.prob <- null.prob[!isna]
+			}
+			universe <- universe[!isna]
+		}
 		if(restrict.universe) {
 			i <- universe %in% GeneID.PathID[,1]
 			universe <- universe[i]
-			if(!is.null(prior.prob)) prior.prob <- prior.prob[i]
+			if(!is.null(null.prob)) null.prob <- null.prob[i]
 			if(!is.null(covariate)) covariate <- covariate[i]
 		}
 	}
 
-#	Consolidate any replicated entries in universe, averaging corresponding prior.probs
+#	Consolidate any replicated entries in universe, averaging corresponding null.probs
 	if(anyDuplicated(universe)) {
 		d <- duplicated(universe)
 		if(!is.null(covariate)) {
@@ -166,10 +193,10 @@ kegga.default <- function(de, universe=NULL,  restrict.universe=FALSE, species="
 			n <- rowsum(rep_len(1L,length(universe)),group=universe,reorder=FALSE)
 			covariate <- covariate/n
 		}
-		if(!is.null(prior.prob)) {
-			prior.prob <- rowsum(prior.prob,group=universe,reorder=FALSE)
+		if(!is.null(null.prob)) {
+			null.prob <- rowsum(null.prob,group=universe,reorder=FALSE)
 			n <- rowsum(rep_len(1L,length(universe)),group=universe,reorder=FALSE)
-			prior.prob <- prior.prob/n
+			null.prob <- null.prob/n
 		}
 		universe <- universe[!d]
 	}
@@ -184,42 +211,44 @@ kegga.default <- function(de, universe=NULL,  restrict.universe=FALSE, species="
 	if(sum(i)==0L) stop("Pathways do not overlap with universe")
 	GeneID.PathID <- GeneID.PathID[i,]
 
-#	Get prior.prob trend in DE with respect to the covariate, combining all de lists
+#	Get null.prob trend in DE with respect to the covariate, combining all de lists
 	if(!is.null(covariate)) {
-		if(!is.null(prior.prob)) message("prior.prob being recomputed from covariate")
+		if(!is.null(null.prob)) message("null.prob being recomputed from covariate")
 		covariate <- as.numeric(covariate)
 		isDE <- (universe %in% unlist(de))
-		o <- order(covariate)
-		prior.prob <- covariate
-		span <- approx(x=c(20,200),y=c(1,0.5),xout=sum(isDE),rule=2,ties=list("ordered",mean))$y
-		prior.prob[o] <- tricubeMovingAverage(isDE[o],span=span)
-		if(plot) barcodeplot(covariate, index=isDE, worm=TRUE, span.worm=span, main="DE status vs covariate")
+		nDE <- sum(isDE)
+		if(identical(nDE,0L)) {
+			message("No DE genes")
+			null.prob <- covariate <- NULL
+		} else {
+			null.prob <- goanaTrend(isDE,covariate,plot=plot)
+		}
 	}
 
 #	Overlap pathways with DE genes
 #	Create incidence matrix (X) of gene.pathway by DE sets
-	if(is.null(prior.prob)) {
+	if(is.null(null.prob)) {
 		X <- matrix(1,nrow(GeneID.PathID),nsets+1)
 		colnames(X) <- c("N",names(de))
 	} else {
-		names(prior.prob) <- universe
+		names(null.prob) <- universe
 		X <- matrix(1,nrow(GeneID.PathID),nsets+2)
-		X[,nsets+2] <- prior.prob[GeneID.PathID[,1]]
+		X[,nsets+2] <- null.prob[GeneID.PathID[,1]]
 		colnames(X) <- c("N",names(de),"PP")
 	}
 	for (s in 1:nsets) X[,s+1] <- (GeneID.PathID[,1] %in% de[[s]])
 
-#	Count #genes and #DE genes and sum prior.prob for each pathway
+#	Count #genes and #DE genes and sum null.prob for each pathway
 	S <- rowsum(X, group=GeneID.PathID[,2], reorder=FALSE)
 
 #	Overlap tests
 	PValue <- matrix(0,nrow=nrow(S),ncol=nsets)
 	colnames(PValue) <- paste("P", names(de), sep=".")
 	nde <- lengths(de, use.names=FALSE)
-	if(!is.null(prior.prob)) {
+	if(!is.null(null.prob)) {
 
 #		Probability ratio for each pathway vs rest of universe
-		SumPP <- sum(prior.prob)
+		SumPP <- sum(null.prob)
 		M2 <- NGenes-S[,"N"]
 		Odds <- S[,"PP"] / (SumPP-S[,"PP"]) * M2 / S[,"N"]
 
@@ -288,10 +317,10 @@ getKEGGPathwayNames <- function(species.KEGG=NULL, remove.qualifier=FALSE)
 	PathID.PathName
 }
 
-topKEGG <- function(results, sort = NULL, number = 20L, truncate.path=NULL)
+topKEGG <- function(results, sort = NULL, number = 20L, truncate.path = NULL, p.value = 1)
 #	Extract top KEGG pathways from kegga output 
 #	Gordon Smyth and Yifang Hu
-#	Created 15 May 2015. Modified 25 Jan 2016.
+#	Created 15 May 2015. Modified 22 Dec 2022.
 {
 #	Check results
 	if(!is.data.frame(results)) stop("results should be a data.frame.")
@@ -317,12 +346,16 @@ topKEGG <- function(results, sort = NULL, number = 20L, truncate.path=NULL)
 		if(!length(isort)) stop("sort column not found in results")
 	}
 
-#	Sort by minimum p-value for specified gene lists
+#	Filter by minimum p-value for specified gene lists
 	P.col <- 2L+nsets+isort
 	if(nsets==1L)
 		P <- results[,P.col]
 	else
 		P <- do.call(pmin,results[,P.col,drop=FALSE])
+	if(p.value < 1) number <- min(number, sum(P <= p.value))
+	if(number < 1L) return(results[integer(0),])
+
+#	Sort by minimum p-value
 	o <- order(P,results$N,results$Pathway)
 	tab <- results[o[1L:number],,drop=FALSE]
 
