@@ -83,13 +83,13 @@ getLayout <- function(gal,guessdups=FALSE)
 }
 
 getDupSpacing <- function(ID)
-#  Find the valid ndups and spacing values for a set of IDs
-#	Assumes at least one probe with a unique ID, from which
+#  Determine ndups and spacing values for a set of IDs.
+#  Assumes at least one probe with a unique ID, from which
 #  spacing can be determined.
 #  Gordon Smyth
-#  15 Oct 2008
+#  Created 15 Oct 2008. Last revised 12 Apr 2020.
 {
-	if(any(is.na(ID))) return(list(ndups=NA,spacing=NA))
+	if(anyNA(ID)) return(list(ndups=NA,spacing=NA))
 	ID <- as.factor(ID)
 	nspots <- length(ID)
 
@@ -179,7 +179,7 @@ readSpotTypes <- function(file="SpotTypes.txt",path=NULL,sep="\t",check.names=FA
 controlStatus <- function(types, genes, spottypecol="SpotType", regexpcol, verbose=TRUE)
 #	Set status of each spot (row)
 #	Gordon Smyth
-#	19 Oct 2003.  Last modified 19 Sep 2015.
+#	19 Oct 2003.  Last modified 9 Jun 2020.
 {
 #	Check types
 	if(!is.data.frame(types)) stop("types must be a data.frame")
@@ -229,7 +229,7 @@ controlStatus <- function(types, genes, spottypecol="SpotType", regexpcol, verbo
 #	Set spot status
 	spottype <- as.character(types[,spottypecol])
 	if(default <- all(types[1,regexpcol]=="*")) {
-		status <- rep(spottype[1],nspots)
+		status <- rep_len(spottype[1],nspots)
 		if(ntypes==1) return(status)
 	} else
 		status <- character(nspots)
@@ -279,7 +279,7 @@ trimWhiteSpace <- function(x)
 }
 
 protectMetachar <- function(x)
-#	Insert backslashs before an metacharacters (to allow them to be included in search strings)
+#	Insert backslashs before metacharacters (to allow them to be included in search strings)
 #	Note that backslashs themselves are not handled
 #	Gordon Smyth
 #	9 June 2004. Last modified 5 Jan 2007.
